@@ -64,7 +64,7 @@ def int2hex(x: int) -> str:
 
 
 def int2asc(x: int) -> str:
-    """10进制转ascii码"""
+    """ascii码值转对应字符"""
     return chr(x)
 
 
