@@ -2,6 +2,7 @@ import paramiko
 import os
 import sys
 import logging
+import psutil
 import functools
 import subprocess
 import tempfile
@@ -22,7 +23,7 @@ logger = logging.getLogger(__name__)
 
 class ExecShellRemote:
     """
-    执行linux shell命令
+    执行远程linux shell命令
     """
 
     def __init__(self, hostname: str, port: int, username: str, password: str):
@@ -268,3 +269,19 @@ def schedule_job(func, blocking=False, **kwargs):
 
     scheduler.add_job(func, **kwargs)
     scheduler.start()
+
+
+def kill_child_process(pid):
+    parent = psutil.Process(pid)
+    for child in parent.children(recursive=True):
+        logger.info("kill child_process {}".format(child))
+        child.kill()
+
+
+def exit_gracefully(signum, frame):
+    logger.info('Receive signal {} frame {}'.format(signum, frame))
+    pid = os.getpid()
+    kill_child_process(pid)
+    parent = psutil.Process(pid)
+    logger.info("kill self {}".format(parent))
+    parent.kill()
