@@ -120,3 +120,10 @@ def path(p):
 
 def _combine_path(path_a, path_b):
     pass
+
+
+def gain_path_files(_path):
+    files = list(list(os.walk(_path))[0])[2]
+
+    return files
+
